import {HttpException, HttpStatus, Injectable} from "@nestjs/common";
import {Constants} from "src/utils/constants";
import {ResponseUtils} from "src/utils/response.utils";
import {BlogTagRepository} from "./blog-tag.repository";
import {CreateBlogTagDto} from "./dto/create-blog-tag.dto";
import {UpdateBlogTagDto} from "./dto/update-blog-tag.dto";
import {BlogTag} from "./entities/blog-tag.entity";

@Injectable()
export class BlogTagService {
    constructor(
        private readonly repository: BlogTagRepository
    ) {
    }

    async create(dto: CreateBlogTagDto): Promise<BlogTag | Error> {
        const res: any = await this.repository.findTagByTagName(dto.tagName);
        if (res.length > 0) {
            throw new HttpException(
                "Tag name already exists.",
                HttpStatus.BAD_REQUEST
            );
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Blog tag created successfully", "data", data);
    }

    async findAll(): Promise<BlogTag[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Blog tag fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdateBlogTagDto): Promise<BlogTag | Error> {
        const res: any = await this.repository.findOneEntity(id);
        if (!res) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Blog tag updated successfully", "data", data);
    }

    async findOne(id: string): Promise<BlogTag[] | Error> {
        const data = await this.repository.findByFilterQuery({id: id});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Blog tag fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Blog tag deleted successfully");
    }
}
