import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import {Constants} from "src/utils/constants";
import {AdminAuthGuard} from "src/core/guards/admin-auth.guard";
import {FileFieldsInterceptor} from "@nestjs/platform-express";
import {UploadedMulterFileI} from "../SpacesModule/SpacesService";
import {CareerDepartmentService} from "./career-department.service";
import {CreateCareerDepartmentDto} from "./dto/create-career-department.dto";
import {UpdateCareerDepartmentDto} from "./dto/update-career-department.dto";

@Controller({path: "career-department", version: Constants.API_VERSION_1})

export class CareerDepartmentController {
    constructor(private readonly service: CareerDepartmentService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            {name: "logo", maxCount: 1}
        ]
    ))
    create(@Body() dto: CreateCareerDepartmentDto,
           @UploadedFiles() files: {
               logo: UploadedMulterFileI
           }) {
        return this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            {name: "logo", maxCount: 1}
        ]
    ))
    update(
        @Param("id") id: string,
        @Body() dto: UpdateCareerDepartmentDto,
        @UploadedFiles() files: {
            logo: UploadedMulterFileI
        }) {
        return this.service.update(id, dto, files);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
