import {Body, Controller, Delete, Get, Param, Patch, Post, UseGuards} from '@nestjs/common';
import {Constants} from 'src/utils/constants';
import {SiteSocialLinksService} from './site-social-links.service';
import {CreateSiteSocialLinksDto} from './dto/create-site-social-links.dto';
import {UpdateSiteSocialLinksDto} from './dto/update-site-social-links.dto';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';

@Controller({path: 'site-social-link', version: Constants.API_VERSION_1})

export class SiteSocialLinksController {
    constructor(private readonly service: SiteSocialLinksService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateSiteSocialLinksDto) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    update(@Param('id') id: string, @Body() dto: UpdateSiteSocialLinksDto) {
        return this.service.update(id, dto);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
